pub struct Rollback {
pub type: i32,
pub removed_transaction_ids: Vec<Vec<u8>>,
pub removed_blocks: Vec<Block>,
pub rollback_state_update: Option<StateUpdate>,
}Fields
type: i32removed_transaction_ids: Vec<Vec<u8>>removed_blocks: Vec<Block>rollback_state_update: Option<StateUpdate>Implementations
Sourceimpl Rollback
impl Rollback
Sourcepub fn type(&self) -> RollbackType
pub fn type(&self) -> RollbackType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: RollbackType)
pub fn set_type(&mut self, value: RollbackType)
Sets type to the provided enum value.