Struct waves_rust::waves_proto::node::grpc::ActivationStatusResponse
source · pub struct ActivationStatusResponse {
pub height: i32,
pub voting_interval: i32,
pub voting_threshold: i32,
pub next_check: i32,
pub features: Vec<FeatureActivationStatus>,
}Fields
height: i32voting_interval: i32voting_threshold: i32next_check: i32features: Vec<FeatureActivationStatus>Trait Implementations
sourceimpl Clone for ActivationStatusResponse
impl Clone for ActivationStatusResponse
sourcefn clone(&self) -> ActivationStatusResponse
fn clone(&self) -> ActivationStatusResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ActivationStatusResponse
impl Debug for ActivationStatusResponse
sourceimpl Default for ActivationStatusResponse
impl Default for ActivationStatusResponse
sourceimpl Message for ActivationStatusResponse
impl Message for ActivationStatusResponse
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8, Global> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8, Global> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8, Global> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8, Global> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self. Read moresourceimpl PartialEq<ActivationStatusResponse> for ActivationStatusResponse
impl PartialEq<ActivationStatusResponse> for ActivationStatusResponse
sourcefn eq(&self, other: &ActivationStatusResponse) -> bool
fn eq(&self, other: &ActivationStatusResponse) -> bool
impl StructuralPartialEq for ActivationStatusResponse